/**
 * 文件信息
 *
 * @export
 * @interface FileInfo
 */
export interface FileInfo {
    id?: string;
    key?: string;
    name?: string;
    type?: string;
    size?: string;
    originPath?: string;
    thumbPath?: string;
    createTime?: string;
    status?: number | string;
    base64?: string;
    params?: Object;
    token?: string;
}
/**
 * 微信支付参数
 *
 * @export
 * @interface WechatPayParams
 */
export interface WechatPayParams {
    appid: string;
    partnerid: string;
    prepayid: string;
    package: string;
    noncestr: string;
    timestamp: string;
    sign: string;
}
/**
 * 经纬度
 * @export
 * @interface LngLat
 */
export interface LngLat {
    longitude?: string;
    latitude?: string;
    lng?: string;
    lat?: string;
    N?: string;
    L?: string;
}
/**
 * 位置
 * @export
 * @interface PositionInfo
 */
export interface PositionInfo {
    longitude: string;
    latitude: string;
    hasAccuracy?: boolean;
    accuracy?: number;
    address: string;
    province?: string;
    road?: string;
    speed?: number;
    bearing?: number;
    satellites?: number;
    time?: string;
}
/**
 *分页
 *
 * @export
 * @interface Pagination
 * 共多少页的计算方式：Math.ceil(totalCount / pageSize)
 */
export interface Pagination {
    startRow?: number;
    endRow?: number;
    pageNo?: number;
    pageSize?: number;
    pageCount?: number;
    pageTime?: string | number | Date;
    totalCount?: number;
    condition?: any;
}
/**
 * 浏览器Model
 *
 * @export
 * @interface Browser
 */
export interface Browser {
    title?: string;
    url: string;
    secureURL?: any;
    isLoaded?: boolean;
    progress?: number;
    progressDom?: any;
    share?: Share;
    eventHandler?: (result: any) => void;
}
/**
 * 分享Model
 *
 * @export
 * @interface Share
 */
export interface Share {
    title?: string;
    banner?: string;
    url: string;
    thumb?: string;
    describe?: string;
}
/**
 * 用户信息
 *
 * @export
 * @interface UserInfo
 */
export interface UserInfo {
    id: string;
    name?: string;
    portrait?: string;
}
/**
 * 聊天消息
 *
 * @export
 * @interface ChatMessage
 */
export interface ChatMessage {
    messageId: string;
    userId: string;
    userName: string;
    userPortrait?: string;
    toUserId: string;
    time: number | string;
    content: string;
    status?: string;
}
/**
 * 选项条目
 *
 * @export
 * @interface Item
 */
export interface Item {
    id: string;
    name: string;
    describe?: string;
    image?: string;
    selected?: boolean;
}
